@@ -1,4 +1,4 @@
-// Auto generated 2021-10-10 23:40:54 +0300
+// Auto generated 2022-03-29 22:40:59 +0300
 extern crate phf_codegen;
 
 use std::env;
@@ -46,7 +46,6 @@ fn main() {
             .entry("aero")
             .entry("aetna")
             .entry("af")
-            .entry("afamilycompany")
             .entry("afl")
             .entry("africa")
             .entry("ag")
@@ -198,7 +197,6 @@ fn main() {
             .entry("brussels")
             .entry("bs")
             .entry("bt")
-            .entry("budapest")
             .entry("bugatti")
             .entry("build")
             .entry("builders")
@@ -322,7 +320,6 @@ fn main() {
             .entry("crs")
             .entry("cruise")
             .entry("cruises")
-            .entry("csc")
             .entry("cu")
             .entry("cuisinella")
             .entry("cv")
@@ -381,7 +378,6 @@ fn main() {
             .entry("drive")
             .entry("dtv")
             .entry("dubai")
-            .entry("duck")
             .entry("dunlop")
             .entry("dupont")
             .entry("durban")
@@ -515,7 +511,6 @@ fn main() {
             .entry("gives")
             .entry("giving")
             .entry("gl")
-            .entry("glade")
             .entry("glass")
             .entry("gle")
             .entry("global")
@@ -741,7 +736,6 @@ fn main() {
             .entry("lipsy")
             .entry("live")
             .entry("living")
-            .entry("lixil")
             .entry("lk")
             .entry("llc")
             .entry("llp")
@@ -842,6 +836,7 @@ fn main() {
             .entry("mtr")
             .entry("mu")
             .entry("museum")
+            .entry("music")
             .entry("mutual")
             .entry("mv")
             .entry("mw")
@@ -898,7 +893,6 @@ fn main() {
             .entry("nz")
             .entry("obi")
             .entry("observer")
-            .entry("off")
             .entry("office")
             .entry("okinawa")
             .entry("olayan")
@@ -999,7 +993,6 @@ fn main() {
             .entry("quest")
             .entry("racing")
             .entry("radio")
-            .entry("raid")
             .entry("re")
             .entry("read")
             .entry("realestate")
@@ -1076,7 +1069,6 @@ fn main() {
             .entry("schule")
             .entry("schwarz")
             .entry("science")
-            .entry("scjohnson")
             .entry("scot")
             .entry("sd")
             .entry("se")
@@ -1347,7 +1339,6 @@ fn main() {
             .entry("xn--3ds443g")
             .entry("xn--3e0b707e")
             .entry("xn--3hcrj9c")
-            .entry("xn--3oq18vl8pn36a")
             .entry("xn--3pxu8k")
             .entry("xn--42c2d9a")
             .entry("xn--45br5cyl")
